# -*- coding: utf-8 -*-
"""
Created on Sun May 30 16:58:10 2021

@author: Daniel Ruth
"""

import matplotlib.pyplot as plt
import numpy as np
import matplotlib
import copy
import os

# update this with the location of the main directory
folder_base = r'L:\DWWE\analysis\dan\trajectories_paper_shared_data\\'

casenames = ['A_wave1p2Hz_wind11p7mps_3_20210607',
             'A_wave1p6Hz_wind11p7mps_2_20210603']

for ci,casename in enumerate(casenames):
    
    # the sub-folder in which data for this plot is stored
    folder_case = folder_base + 'FIGURE2_'+casename
    
    # load all of the text files in which numerical data is stored
    files = os.listdir(folder_case)
    files = [f for f in files if '.txt' in f]
    d = {key[:-4]:np.loadtxt(folder_case+'\\'+key) for key in files}
    
    # make the figure and axes
    fig,axs = plt.subplots(3,1,figsize=(6,8),sharex=True,sharey=False)
    ax_slope,ax_n,ax_dist = axs
    
    '''
    Transient wave slope
    '''
    ax_slope.plot(d['t_amplitude_s'],d['waveslope'])
    ax_slope.set_ylabel(r'$ak$')
    
    '''
    Transient number of bubbles
    '''
    ax_n.plot(d['t_nbubs_s'],d['nbubs_ensavg']) # ensemble average
    ax_n.fill_between(d['t_nbubs_s'],d['nbubs_ensavg']-d['nbubs_ensstd']/2,d['nbubs_ensavg']+d['nbubs_ensstd']/2,alpha=0.5)
    ax_n.set_ylabel(r'$n(t)$')
    
    '''
    Transient size distribution
    '''
    
    # color for the size distribution
    cmap = copy.copy(plt.cm.plasma)
    cmap.set_bad(cmap(0))
    ax_dist.set_facecolor('gray')
    norm = matplotlib.colors.LogNorm(vmin=1e2,vmax=1e5)
    c=ax_dist.pcolormesh(d['t_depthdist_s'],d['z_depthdist_m']*100,d['depthdist_perm3'],cmap=cmap,norm=norm)
    ax_dist.set_xlabel(r'$t$ [s]')
    ax_dist.set_ylabel(r'$z$ [cm]')
    
    # ensemble-average surface elevation, and standard devation
    ax_dist.fill_between(d['t_eta_s'],d['eta_ensavg']*100-d['eta_ensstd']*100,d['eta_ensavg']*100+d['eta_ensstd']*100,color='cyan',alpha=0.5)
    ax_dist.plot(d['t_eta_s'],d['eta_ensavg']*100,color='cyan')
    
    # wave amplitude
    ax_dist.plot(d['t_amplitude_s'],d['amplitude_m']*100,ls='--',color='g')
    
    '''
    Final touches on figure
    '''
    
    fig.suptitle(casename)
    fig.tight_layout()