# -*- coding: utf-8 -*-
"""
Created on Thu Jul  8 10:01:20 2021

@author: danjr
"""

import matplotlib.pyplot as plt
import numpy as np
import matplotlib
import copy
import os

# update this with the location of the main directory
folder_base = r'L:\DWWE\analysis\dan\trajectories_paper_shared_data\\'

folder_depthdists = folder_base + r'FIGURE3_depthdists\\'

# get the names of all the conditions
condition_names = os.listdir(folder_depthdists)

# values of the central forcing frequency and nominal wind speed
f0_vals = [0.0,1.0,1.2,1.4,1.6,1.8] # Hz
Unom_vals = [9.7,10.7,11.7] # m/s

# colormap for the value of ak in the dimensionless plot
cmap_ak = copy.copy(plt.get_cmap('cividis'))
cmap_ak.set_under('gray')
norm_ak = matplotlib.colors.Normalize(vmin=0.15, vmax=0.35)
m_ak = matplotlib.cm.ScalarMappable(norm=norm_ak, cmap=cmap_ak)


fig_d,axs_d = plt.subplots(2,3,figsize=(9,7),sharex=True,sharey=True)
fig_nd,axs_nd = plt.subplots(1,2,figsize=(9,4),sharex=False,sharey=False)
#axs_d = axs_d

'''
Time-averaged depth distributions
'''

for fi,f0 in enumerate(f0_vals):
    
    # axes for the dimensional data
    ax_d = axs_d.flatten()[fi]

    for ui,Unom in enumerate(Unom_vals):
        
        # get the name of the subfolder corresponding to this condition
        condition_name = 'f0_'+'{:1.1f}'.format(f0)+'_Hz_Unom_'+'{:1.1f}'.format(Unom)+'_mps'
        folder_condition = folder_depthdists+r'\\'+condition_name+'\\'
        
        # load the data for this condition
        files = os.listdir(folder_depthdists+r'\\'+condition_name)        
        d = {key[:-4]:np.loadtxt(folder_condition+key) for key in files}
        
        # plot the dimensional data
        ax_d.semilogx(d['depthdist_perm3'],d['z_depthdist_m']*100,label='{:1.1f}'.format(d['U0']))
        
        # plot the non-dimensional value
        depthdist_nondim = d['depthdist_perm3']/np.nanmax(d['depthdist_perm3'])
        z_nondim = d['z_depthdist_m'] / d['a0']
        color = m_ak.to_rgba(d['a0']*d['kp'])
        axs_nd[0].semilogx(depthdist_nondim,z_nondim,color=color,alpha=0.8)
    
    # set the title (giving f_0) and the legend (giving U_0) for this f_0
    ax_d.set_title(r'$f_0 = '+'{:1.1f}'.format(f0)+'$ Hz')
    ax_d.legend(title=r'$U_0$ [m/s]',frameon=False)
    
# set axes labels for the dimensional plot
[ax_d.set_ylabel(r'$z$ [cm]') for ax in axs_d[:,0]]
[ax_d.set_xlabel(r'$N_z(z)$ [1/m$^{3}$]') for ax in axs_d[-1,:]]

# axes labels for the dimensionless depth distribution plots
axs_nd[0].set_xlabel(r'$\langle N_z(z) \rangle /  \langle N_z(z) \rangle_\mathrm{max} $')
axs_nd[0].set_ylabel(r'$z/a_0$')

# make a colorbar denoting ak for the dimensionless plot
cb = fig_nd.colorbar(m_ak,ax=axs_nd[0],orientation='horizontal')
cb.set_label(r'$a_0 k_\mathrm{p}$')
    
'''
Minimum entrainment depths
'''
    
# load the data
folder_mindepth = folder_base + r'FIGURE3_minentrainmentdepths\\'
files = os.listdir(folder_mindepth)
d = {key[:-4]:np.loadtxt(folder_mindepth+key) for key in files}

# plot it
axs_nd[1].plot(d['PDF_zminbya'],d['zminbya'])

# axes labels
axs_nd[1].set_ylabel(r'$z_\mathrm{min}/a$')
axs_nd[1].set_xlabel(r'PDF($z_\mathrm{min}/a$)')

'''
Finish the figures
'''

fig_d.tight_layout()
fig_nd.tight_layout()