# -*- coding: utf-8 -*-
"""
Created on Thu Jul  8 10:01:20 2021

@author: danjr
"""

import matplotlib.pyplot as plt
import numpy as np
import os

# update this with the location of the main directory
folder_base = r'L:\DWWE\analysis\dan\trajectories_paper_shared_data\\'



'''
Plots of bubble velocity distributions by depth
'''

folder_bydepth = folder_base + r'FIGURE4_bydepth\\'


fig,axss = plt.subplots(2,3,figsize=(9,6),sharex=True,sharey='row')

comps = ['x','y','z'] # directional components

for vi in range(3):
    
    comp = comps[vi]
    axs = axss[:,vi] # the two axes for this component
    
    folder_comp = folder_bydepth+r'\\'+comp+'_direction\\'
    files = os.listdir(folder_comp)        
    d = {key[:-4]:np.loadtxt(folder_comp+key) for key in files}
    
    # distributions by depth
    axs[0].pcolormesh(d['vi_by_cp_veldepth'],d['z_by_a_veldepth'],d['veldepth'],cmap='gray_r')
    axs[0].plot(d['meanvivsdepth'],d['z_by_a_meanvivsdepth'],color='r',label=r'$\langle v_x \rangle(z) / c_\mathrm{p}$')
    
    # 1d distributions for the upper and lower layers
    axs[1].plot(d['vi_by_cp_dist1d'],d['dist1d_upper'],color='g',label=r'$-1 \leq z/a < 0$')
    axs[1].plot(d['vi_by_cp_dist1d'],d['dist1d_lower'],color='purple',label=r'$-1 \leq z/a < 0$')
    
    axs[1].set_xlabel(r'$v_'+comp+' / c_\mathrm{p}$')
    
axss[0,0].set_ylabel(r'$z/a$')
axss[1,0].set_ylabel(r'PDF')

fig.tight_layout()
    
'''
Joint distributions of bubble and water velocity for x and z directions
'''

fig,axs = plt.subplots(1,2,figsize=(9,4),sharey=True)

folder_jointveldists = folder_base + r'FIGURE4_jointveldists\\'

for vii,comp in enumerate(['x','z']):
    
    ax = axs[vii]
    
    folder_comp = folder_jointveldists+r'\\'+comp+'_direction\\'
    files = os.listdir(folder_comp)        
    d = {key[:-4]:np.loadtxt(folder_comp+key) for key in files}
    
    ax.pcolormesh(d['vi_by_cp'],d['ui_by_cp'],d['joint_dist'],cmap='gray_r')
    ax.set_xlabel(r'$v_'+comp+r'/c_\mathrm{p}$')
    
axs[0].set_ylabel(r'$u_i/c_\mathrm{p}$')

fig.tight_layout()

'''
Timeseries of surface elevation, modeled velocity, and measured velocity
'''

folder_velocity = folder_base+r'\\FIGURE4_velocity\\'
files = os.listdir(folder_velocity)        
d = {key[:-4]:np.loadtxt(folder_velocity+key) for key in files}

fig,axs = plt.subplots(1,2,figsize=(9,4))

# surface elevation
ax = axs[0]
ax.plot(d['tbyT_eta'],d['etakp'])
ax.set_xlabel(r'$t/T$')
ax.set_ylabel(r'$\eta k_\mathrm{p}$ (upstream)')

# measured and modeled velocity (will need to zoom in on x axis)
ax = axs[1]
ax.plot(d['twgbyT'],d['uwgbycp'],color='k',label='modeled given surface elevation')
ax.plot(d['tldvbyT'],d['uldvbycp'],color='limegreen',label='measured by LDV')
ax.legend(frameon=False)
ax.set_xlabel(r'$t/T$')
ax.set_ylabel(r'$u_x / c_\mathrm{p}$ (at LDV)')

fig.tight_layout()